package com.tencent.txcplayeradapterdemo;

import android.app.Activity;
import android.content.Intent;
import android.os.Build;
import android.os.Bundle;
import android.util.Log;
import android.view.View;
import android.widget.Toast;

import com.tencent.liteav.demo.superplayer.SuperPlayerDef;
import com.tencent.liteav.demo.superplayer.SuperPlayerModel;
import com.tencent.liteav.demo.superplayer.SuperPlayerView;
import com.tencent.txcplayeradapter.ITXCPlayerAssistor;
import com.tencent.txcplayeradapter.ITXCRequestVideoInfoCallback;
import com.tencent.txcplayeradapter.TXCPlayerAdapter;
import com.tencent.txcplayeradapter.model.TXCImageSpriteInfo;
import com.tencent.txcplayeradapter.model.TXCKeyFrameDescInfo;
import com.tencent.txcplayeradapter.model.TXCStreamingInfo;
import com.tencent.txcplayeradapter.model.TXCVideoBasicInfo;

import java.util.List;

public class VideoActivity extends Activity implements SuperPlayerView.OnSuperPlayerViewCallback {

    private static final String TAG = "VideoActivity";
    private static final String EXTRA_FILEID = "fileId";
    private static final String EXTRA_PSIGN = "pSign";

    private SuperPlayerView mSuperPlayerView;
    private String mFileId, mPSign;
    private ITXCPlayerAssistor mPlayerAssistor;

    @Override
    protected void onCreate(Bundle savedInstanceState) {
        super.onCreate(savedInstanceState);

        setContentView(R.layout.activity_video);
        Intent intent = getIntent();
        if (intent != null) {
            mFileId = intent.getStringExtra(EXTRA_FILEID);
            mPSign = intent.getStringExtra(EXTRA_PSIGN);
        }
        mSuperPlayerView = findViewById(R.id.sv_videoplayer);
        mSuperPlayerView.setPlayerViewCallback(this);
        if (mPSign != null && mFileId != null) {
            startPlay();
        } else {
            Toast.makeText(this, "pSign = null || fileId = null", Toast.LENGTH_SHORT).show();
            finish();
        }
    }

    private void startPlay() {
        mPlayerAssistor = TXCPlayerAdapter.createPlayerAssistor(mFileId, mPSign);
//        mPlayerAssistor = TXCPlayerAdapter.createEncryptedPlayerAssistor(mFileId,mPSign);
        mPlayerAssistor.requestVideoInfo(new ITXCRequestVideoInfoCallback() {

            @Override
            public void onError(int errCode, String msg) {
                Log.d(TAG, "onError msg = " + msg);
                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        Toast.makeText(VideoActivity.this, "onError msg = " + msg, Toast.LENGTH_SHORT).show();
                        finish();
                    }
                });
            }

            @Override
            public void onSuccess() {
                Log.d(TAG, "onSuccess");

                List<TXCKeyFrameDescInfo> keyFrameDescInfos = mPlayerAssistor.getKeyFrameDescInfo();
                Log.d(TAG, "keyFrameDescInfos = " + keyFrameDescInfos);

                TXCStreamingInfo streamingInfo = mPlayerAssistor.getStreamingInfo();
                Log.d(TAG, "streamingInfo = " + streamingInfo);

                TXCVideoBasicInfo videoBasicInfo = mPlayerAssistor.getVideoBasicInfo();
                Log.d(TAG, "videoBasicInfo = " + videoBasicInfo);

                TXCImageSpriteInfo imageSpriteInfo = mPlayerAssistor.getImageSpriteInfo();
                Log.d(TAG, "imageSpriteInfo = " + imageSpriteInfo);

                runOnUiThread(new Runnable() {
                    @Override
                    public void run() {
                        if (mPlayerAssistor.getStreamingInfo() != null) {
                            SuperPlayerModel model = new SuperPlayerModel();
                            model.url = mPlayerAssistor.getStreamingInfo().playUrl;
                            mSuperPlayerView.playWithModel(model);
                        } else {
                            Toast.makeText(VideoActivity.this, "streamInfo = null", Toast.LENGTH_SHORT).show();
                            finish();
                        }
                    }
                });
            }
        });
    }

    @Override
    public void onBackPressed() {
        finish();
        super.onBackPressed();
    }

    @Override
    protected void onDestroy() {
        super.onDestroy();
        if (mSuperPlayerView != null) {
            mSuperPlayerView.release();
            if (mSuperPlayerView.getPlayerMode() != SuperPlayerDef.PlayerMode.FLOAT) {
                mSuperPlayerView.resetPlayer();
            }
        }
        if (mPlayerAssistor != null) {
            TXCPlayerAdapter.destroyPlayerAssistor(mPlayerAssistor);
            mPlayerAssistor = null;
        }
    }


    @Override
    protected void onPause() {
        super.onPause();
        Log.i(TAG, "onPause state :" + mSuperPlayerView.getPlayerState());
        if (mSuperPlayerView.getPlayerMode() != SuperPlayerDef.PlayerMode.FLOAT) {
            mSuperPlayerView.onPause();
        }
    }

    @Override
    protected void onResume() {
        super.onResume();
        if (mSuperPlayerView.getPlayerState() == SuperPlayerDef.PlayerState.PLAYING || mSuperPlayerView.getPlayerState() == SuperPlayerDef.PlayerState.PAUSE) {
            Log.i(TAG, "onResume state :" + mSuperPlayerView.getPlayerState());
            mSuperPlayerView.onResume();
            if (mSuperPlayerView.getPlayerMode() == SuperPlayerDef.PlayerMode.FLOAT) {
                mSuperPlayerView.switchPlayMode(SuperPlayerDef.PlayerMode.WINDOW);
            }
        }
        if (mSuperPlayerView.getPlayerMode() == SuperPlayerDef.PlayerMode.FULLSCREEN) {
            //隐藏虚拟按键，并且全屏
            View decorView = getWindow().getDecorView();
            if (decorView == null) return;
            if (Build.VERSION.SDK_INT > 11 && Build.VERSION.SDK_INT < 19) { // lower api
                decorView.setSystemUiVisibility(View.GONE);
            } else if (Build.VERSION.SDK_INT >= 19) {
                int uiOptions =
                        View.SYSTEM_UI_FLAG_HIDE_NAVIGATION | View.SYSTEM_UI_FLAG_IMMERSIVE_STICKY | View.SYSTEM_UI_FLAG_FULLSCREEN;
                decorView.setSystemUiVisibility(uiOptions);
            }
        }
    }

    @Override
    public void onStartFullScreenPlay() {

    }

    @Override
    public void onStopFullScreenPlay() {

    }

    @Override
    public void onClickFloatCloseBtn() {
        // 点击悬浮窗关闭按钮，那么结束整个播放
        mSuperPlayerView.resetPlayer();
        finish();
    }

    @Override
    public void onClickSmallReturnBtn() {
        // 点击小窗模式下返回按钮，开始悬浮播放
//        showFloatWindow();
        finish();
    }


    @Override
    public void onStartFloatWindowPlay() {
        // 开始悬浮播放后，直接返回到桌面，进行悬浮播放
        Intent intent = new Intent(Intent.ACTION_MAIN);
        intent.setFlags(Intent.FLAG_ACTIVITY_NEW_TASK);
        intent.addCategory(Intent.CATEGORY_HOME);
        startActivity(intent);
    }

    @Override public void onPlaying() {

    }

    @Override public void onPlayEnd() {

    }

    @Override public void onError(int code) {

    }

    public static void playVideo(Activity activity, String fileId, String pSign) {
        Intent intent = new Intent(activity, VideoActivity.class);
        intent.putExtra(EXTRA_FILEID, fileId);
        intent.putExtra(EXTRA_PSIGN, pSign);
        activity.startActivity(intent);
    }
}