# Android TXCPlayerAdapter 接入说明



## 1. 加密视频播放流程说明



流程图：

```mermaid
sequenceDiagram
participant 客户播放器
participant SDK套件
participant 腾讯云视频后台

客户播放器 ->> SDK套件:请求视频信息（传入fileId+pSign）
SDK套件 ->> 腾讯云视频后台:请求视频信息
腾讯云视频后台 -->> SDK套件:返回视频信息
SDK套件 -->> 客户播放器:返回请求结果(此时可以通过接口获取播放地址，子流信息等)
客户播放器 ->> SDK套件:启动播放，请求视频数据
SDK套件 ->> 腾讯云视频后台:请求视频数据
腾讯云视频后台 -->> SDK套件:返回视频数据（加密的）
SDK套件 ->> SDK套件:对视频进行解密
SDK套件 -->> 客户播放器:返回视频数据（已解密）

```





## 2. 集成SDK

拷贝TXCPlayerAdapter-release-1.0.0.aar 到 libs目录，添加依赖项：implementation(name:'TXCPlayerAdapter-release-1.0.0', ext:'aar')



注意混淆

```
-keep class com.tencent.** { *; }
```



## 3. 使用sdk



#### 初始化TXCPlayerAdatper

**说明**

初始化Adapter，每次

**接口**

```java
TXCPlayerAdapter.init(String appId);
```

**参数说明**

appId：填写 appid（如果使用了子应用，则填 subappid）



#### 销毁TXCPlayerAdatper

**说明**

销毁Adapter，当程序退出后调用。

**接口**

```java
TXCPlayerAdapter.destroy();
```



#### 创建播放器辅助类

**说明**

通过播放器辅助类可以获取播放fileId相关信息以及处理DRM加密接口等。

**接口**

```java
ITXCPlayerAssistor playerAssistor = TXCPlayerAdapter.createPlayerAssistor(String fileId, String pSign);
```

**参数说明**

| 参数名 | 类型   | 描述               |
| ------ | ------ | ------------------ |
| fileId | String | 要播放的视频fileId |
| pSign  | String | 超级播放器签名     |



**销毁播放器辅助类**

**说明**

销毁辅助类，在退出播放器或者切换了下一个视频播放的时候调用。

**接口**

```
TXCPlayerAdapter.destroyPlayerAssistor(ITXCPlayerAssistor assistor);
```



#### 请求视频播放信息

**说明**

本接口会请求腾讯云点播服务器，获取播放视频的流信息等。

**接口**

```java
playerAssistor.requestVideoInfo(ITXCRequestVideoInfoCallback callback);
```

**参数说明**

| 参数名   | 类型                         | 描述         |
| -------- | ---------------------------- | ------------ |
| callback | ITXCRequestVideoInfoCallback | 异步回调函数 |





#### 获取视频的基本信息

**说明**

获取视频信息， 必须是在playerAssistor.requestPlayInfo回调之后才生效。

**接口**

```java
TXCVideoBasicInfo playerAssistor.getVideoBasicInfo();
```

**参数说明**

TXCVideoBasicInfo：参数如下

| 参数名      | 类型   | 描述                 |
| ----------- | ------ | -------------------- |
| name        | String | 视频名称。           |
| duration    | Float  | 视频时长，单位：秒。 |
| description | String | 视频描述。           |
| coverUrl    | String | 视频封面。           |



#### 获取视频流信息

**说明**

获取视频流信息列表，必须是在playerAssistor.requestPlayInfo回调之后才生效。

**接口**

```java
TXCStreamingInfo playerAssistor.getStreamimgInfo();
```

**参数说明**

TXCStreamingInfo

| 参数名     | 类型   | 描述                                       |
| ---------- | ------ | ------------------------------------------ |
| playUrl    | String | 播放 URL。                                 |
| subStreams | List   | 自适应码流子流信息，类型为 SubStreamInfo。 |

SubStreamInfo

| 参数名         | 类型   | 描述                                   |
| -------------- | ------ | -------------------------------------- |
| type           | String | 子流的类型，目前可能的取值仅有 video。 |
| width          | Int    | 子流视频的宽，单位：px。               |
| height         | Int    | 子流视频的高，单位：px。               |
| resolutionName | String | 子流视频在播放器中展示的规格名。       |



#### 获取关键帧打点信息

**说明**

获取视频关键帧打点信息，必须是在playerAssistor.requestPlayInfo回调之后才生效。

**接口**

```java
List<TXCKeyFrameDescInfo> playerAssistor.getKeyFrameDescInfo();
```

**参数说明**

TXCKeyFrameDescInfo

| 参数名     | 类型   | 描述          |
| ---------- | ------ | ------------- |
| timeOffset | Float  | 1.1           |
| content    | String | "片头开始..." |



#### 获取缩略图信息

**说明**

获取缩略图信息，必须是在playerAssistor.requestPlayInfo回调之后才生效。

**接口**

```java
TXCImageSpriteInfo playerAssistor.getImageSpriteInfo();
```

**参数说明**

TCXImageSpriteInfo

| 参数名    | 类型   | 描述                                  |
| --------- | ------ | ------------------------------------- |
| imageUrls | List   | 缩略图下载 URL 数组，类型为 String 。 |
| webVttUrl | String | 缩略图 VTT 文件下载 URL 。            |



